==========
Fangfrisch
==========

Copyright © 2020-2025 Ralph Seichter

Fangfrisch (German for "freshly caught") is a sibling of the `Clam Anti-Virus`_ freshclam utility.
It allows downloading virus definition files that are not official ClamAV canon, e.g. from Sanesecurity_, URLhaus_ and others.
Fangfrisch was designed with security in mind, to be run by an unprivileged user only.

Detailed documentation_ is available online.

.. image:: https://github.com/rseichter/fangfrisch/workflows/Python%20package/badge.svg

.. _documentation: https://rseichter.github.io/fangfrisch/
.. _Clam Anti-Virus: https://www.clamav.net
.. _Sanesecurity: https://sanesecurity.com
.. _URLhaus: https://urlhaus.abuse.ch
